Catalogul manualelor - BookLab
Author: Petre Iordanescu (petre.iordanescu@gmail.com)

Skip to content

BookLab System
(c) 2023 RENware Software Systems

# BCAT Catalog carti - manual de utilizare

Cuprins:

## Introducere

Acest manual descrie utilizarea functionaliatatii "Catalog carti" ce permite accesarea listei cartilor create in sistem si efectuarea de diverse operatii asupra acestora cum ar fi: modificare, previzualuzare, etc.

- Navigare: `<URL general BookLab>/bcat/`
- Audienta: utilizatori finali

## Desrirea ...tbd...

UPCOMING...

Last update: September 24, 2025